@@ -1,12 +1,11 @@
-/* $Id: pdMat.c,v 1.4 2000/07/07 21:20:35 saikat Exp $ 
-
+/*
    Routines for dealing with pdMat objects
 
    Copyright 1997-2005 Douglas M. Bates <bates@stat.wisc.edu>,
-                       Jose C. Pinheiro <jose.pinheiro@pharma.novartis.com>
-		       Saikat DebRoy <saikat@stat.wisc.edu>
+		       Jose C. Pinheiro,
+		       Saikat DebRoy
 
-   This file is part of the nlme library for R and related languages
+   This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
    License, version 2, or at your option, any later version,
    incorporated herein by reference.
@@ -17,11 +16,10 @@
    PURPOSE.  See the GNU General Public License for more
    details.
 
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA
- 
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
+
 */
 
 #include "pdMat.h"
@@ -29,7 +27,7 @@
 
 /* Positive definite matrices */
 
-static void 
+static void
 Chol_pd(double *L, longint *q, double *l)
 {
   longint i, qq = *q;
@@ -52,15 +50,15 @@ logChol_pd(double *L, longint *q, double *l)
   }
 }
 
-void 
+void
 matrixLog_pd(double *L, longint *q, double *l)
 {
   longint i, j, qq = *q, one = 1L, info = 0L;
   if ( qq == 1 ) {
     *L = exp( *l );
   } else {
-    double *vectors = Calloc((size_t) qq * qq, double), 
-      *work1 = Calloc((size_t) qq, double), *work2 = Calloc((size_t) qq, double), 
+    double *vectors = Calloc((size_t) qq * qq, double),
+      *work1 = Calloc((size_t) qq, double), *work2 = Calloc((size_t) qq, double),
       *values = Calloc((size_t) qq, double);
     Chol_pd(L, q, l);
     for(i = 0; i < qq - 1; i++) {
@@ -127,4 +125,3 @@ compSymm_pd(double *L, longint *q, double *l) /* compound symmetry */
     L[i * qp1] = -aux * i;
   }
 }
-
